==> jmb.organization-0.2.7.tar.gz: jmb.organization-0.2.7/jmb/organization/autocomplete_light_registry.py <==
import autocomplete_light

from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from models import Organization, OrganizationGroup, Contact
from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

autocomplete_light.register(
    Organization, search_fields=['code', 'name', 'vat_number'],
)

#: user autocompletes
class UserAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['username', 'last_name', 'first_name', 'email']
    choices = User.objects.all()
    model = User
    autocomplete_js_attributes={
        'minimumCharacters': 1,
        'placeholder' : _('.. to get the complete list'),
    }

    def choices_for_request(self):
        self.choices = User.objects.all()
        q = self.request.GET.get('q', '')
        if q == '..':
            return self.choices
        ret = super(UserAutocomplete, self).choices_for_request()
        return ret

autocomplete_light.register(UserAutocomplete, name="User")

class OrganizationGroupAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['name',]
    choices = OrganizationGroup.objects.all()
    model = OrganizationGroup 
    autocomplete_js_attributes = {
        'minimum_characters': 0, 
        'placeholder' : _('.. to get the complete list'),
    }

    def choices_for_request(self):
        self.choices = OrganizationGroup.objects.all()
        q = self.request.GET.get('q', '')
        if q == '..':
            return self.choices
        ret = super(OrganizationGroupAutocomplete, self).choices_for_request()
        return ret
autocomplete_light.register(OrganizationGroupAutocomplete, name='OrganizationGroup')

#: organization autocompletes
class OrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = Organization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('Organization'),}
    model = Organization
autocomplete_light.register(OrganizationAutocomplete, name="Organization")

class OwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.owners.filter()
    autocomplete_js_attributes = {
        'minimum_characters': 0, 
        'placeholder' : _('click to get the complete list'),
    }
autocomplete_light.register(OwnerOrganizationAutocomplete, name="OwnerOrganization")

class CustomerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers.all()
    autocomplete_js_attributes = {
        'minimum_characters': 0, 
        'placeholder' : _('click to get the complete list'),
    }
autocomplete_light.register(CustomerOrganizationAutocomplete, name="CustomerOrganization")

class CustomerOwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers_owners.filter(status=1)
        
autocomplete_light.register(CustomerOwnerOrganizationAutocomplete, name="CustomerOwnerOrganization")

class SupplierOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.suppliers.all()
autocomplete_light.register(SupplierOrganizationAutocomplete, name="SupplierOrganization")

#: contact autocomplete
class ContactAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['last_name', 'first_name']
    choices = Contact.objects.all()
    autocomplete_js_attributes = {'placeholder': _('Contact'),}
    model = Contact
autocomplete_light.register(ContactAutocomplete, name="Contact")

class OwnerContactAutocomplete(ContactAutocomplete):
    choices = Contact.owners.filter()
autocomplete_light.register(OwnerContactAutocomplete, name="OwnerContact")

class CustomerContactAutocomplete(ContactAutocomplete):
    model = Contact
    filters = {
        'organization_id' : '#id_organization',
    }
    autocomplete_js_attributes = { 
        'minimum_characters': 1, 
        'placeholder' : _('.. to get the complete list'),
    }

autocomplete_light.register(CustomerContactAutocomplete, name="CustomerContact")

class SupplierContactAutocomplete(ContactAutocomplete):
    choices = Contact.suppliers.filter()
autocomplete_light.register(SupplierContactAutocomplete, name="SupplierContact")

class WorkerContactAutocomplete(ContactAutocomplete):
    choices = Contact.workers.filter()
autocomplete_light.register(WorkerContactAutocomplete, name="WorkerContact")

==> jmb.organization-0.3.tar.gz: jmb.organization-0.3/jmb/organization/autocomplete_light_registry.py <==
import autocomplete_light

from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from models import Organization, OrganizationGroup, Contact
from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

autocomplete_light.register(
    Organization, search_fields=['code', 'name', 'vat_number'],
)

#: user autocompletes
class UserAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['username', 'last_name', 'first_name', 'email']
    choices = User.objects.all()
    model = User
    autocomplete_js_attributes = {
        'minimum_characters': 0
    }


autocomplete_light.register(UserAutocomplete, name="User")

class OrganizationGroupAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['name', ]
    choices = OrganizationGroup.objects.all()
    model = OrganizationGroup
    autocomplete_js_attributes = {
        'minimum_characters': 0
    }

autocomplete_light.register(OrganizationGroupAutocomplete, name='OrganizationGroup')

#: organization autocompletes
class OrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = Organization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('Organization'), }
    model = Organization
autocomplete_light.register(OrganizationAutocomplete, name="Organization")

class OwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.owners.filter()
    autocomplete_js_attributes = {
        'minimum_characters': 0,
    }
autocomplete_light.register(OwnerOrganizationAutocomplete, name="OwnerOrganization")

class CustomerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers.all()
    autocomplete_js_attributes = {
        'minimum_characters': 0,
        'placeholder': _('click to get the complete list'),
    }
autocomplete_light.register(CustomerOrganizationAutocomplete, name="CustomerOrganization")

class CustomerOwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers_owners.filter(status=1)

autocomplete_light.register(CustomerOwnerOrganizationAutocomplete, name="CustomerOwnerOrganization")

class SupplierOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.suppliers.all()
autocomplete_light.register(SupplierOrganizationAutocomplete, name="SupplierOrganization")

#: contact autocomplete
class ContactAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['last_name', 'first_name']
    choices = Contact.objects.all()
    autocomplete_js_attributes = {'placeholder': _('Contact'), }
    model = Contact
autocomplete_light.register(ContactAutocomplete, name="Contact")

class OwnerContactAutocomplete(ContactAutocomplete):
    choices = Contact.owners.filter()
autocomplete_light.register(OwnerContactAutocomplete, name="OwnerContact")

class CustomerContactAutocomplete(ContactAutocomplete):
    model = Contact
    filters = {
        'organization_id': '#id_organization',
    }
    autocomplete_js_attributes = {
        'minimum_characters': 0,
    }

autocomplete_light.register(CustomerContactAutocomplete, name="CustomerContact")

class SupplierContactAutocomplete(ContactAutocomplete):
    choices = Contact.suppliers.filter()
autocomplete_light.register(SupplierContactAutocomplete, name="SupplierContact")

class WorkerContactAutocomplete(ContactAutocomplete):
    choices = Contact.workers.filter()
autocomplete_light.register(WorkerContactAutocomplete, name="WorkerContact")
